@@ -9,29 +9,45 @@ from datamodel_code_generator.types import DataType, Types
 
 class DataModelField(DataModelFieldBase):
     _FIELDS_KEYS: Set[str] = {'alias', 'example', 'examples', 'description', 'title'}
-    field: Optional[str] = None
-
-    def get_valid_argument(self, value: Any) -> Union[str, List[Any], Dict[Any, Any]]:
-        if isinstance(value, str):
-            return repr(value)
-        elif isinstance(value, list):
-            return [self.get_valid_argument(i) for i in value]
-        elif isinstance(value, dict):
-            return {
-                self.get_valid_argument(k): self.get_valid_argument(v)
-                for k, v in value.items()
-            }
-        return value
 
     def __init__(self, **values: Any) -> None:
         super().__init__(**values)
+
+    @property
+    def method(self) -> Optional[str]:
+        return self.validator
+
+    @property
+    def validator(self) -> Optional[str]:
+        return None
+        # TODO refactor this method for other validation logic
+        # from datamodel_code_generator.model.pydantic import VALIDATOR_TEMPLATE
+        #
+        # return VALIDATOR_TEMPLATE.render(
+        #     field_name=self.name, types=','.join([t.type_hint for t in self.data_types])
+        # )
+
+    @property
+    def field(self) -> Optional[str]:
+        """for backwards compatibility"""
+        result = str(self)
+        if result == "":
+            return None
+
+        return result
+
+    def __str__(self) -> str:
         field_arguments = [
-            f"{k}={self.get_valid_argument(v)}"
+            f"{k}={repr(v)}"
             for k, v in self.dict(include=self._FIELDS_KEYS).items()
             if v is not None
         ]
-        if field_arguments:
-            self.field = f'Field({"..." if self.required else self.get_valid_argument(self.default)}, {",".join(field_arguments)})'
+        if not field_arguments:
+            return ""
+
+        value_arg = "..." if self.required else repr(self.default)
+        kwargs = ",".join(field_arguments)
+        return f'Field({value_arg}, {kwargs})'
 
 
 class BaseModel(DataModel):
@@ -52,6 +68,8 @@ class BaseModel(DataModel):
         imports: Optional[List[Import]] = None,
     ):
 
+        methods: List[str] = [field.method for field in fields if field.method]
+
         super().__init__(
             name=name,
             fields=fields,  # type: ignore
@@ -63,6 +81,7 @@ class BaseModel(DataModel):
             auto_import=auto_import,
             reference_classes=reference_classes,
             imports=imports,
+            methods=methods,
         )
 
         config_parameters: Dict[str, Any] = {}
